@@ -1,7 +1,7 @@
 #! /usr/bin/env python
 
 """
-ver 2010 09 03 11
+ver 2010 09 03 12
 autor Bartlomiej Ceglik
 e-mail yoyoek[no spam]wp.pl
 """
@@ -273,7 +273,17 @@ def Run_import():
                 location = Call_featch_val(e,'location')
                 desc = Call_featch_val(e, 'description')
                 entryDate = Call_featch_val(e, 'created')
+                if entryDate:
+                    entryDate = ParseStrTime_to_unix(entryDate)
+                    if entryDate < 0:
+                        entryDate = 0
                 modDate = Call_featch_val(e, 'last-modified')
+                if modDate:
+                    modDate = ParseStrTime_to_unix(modDate)
+                    if modDate < 0:
+                        modeDate = 0
+
+                print "entry(%s) mod(%s)" % ( entryDate, modDate )
 
                 ev_ta.append(
                              [cal_id,        '1',                '-1',   tStart,         tEnd,        e['summary'],      location,           desc,               '-1',       '0',        '-1',   '0',    str(entryDate),     str(modDate),        ':UTC', '0']
